@@ -13,5 +13,6 @@ graph.load_local_rooms(hide_private=True)
 graph.apply_nodes_to_graph(hide_user_name=False)
 graph.calculate_edges()
 graph.load_external_users(hide_name=True)
-graph.calculate_external_servers_stats()
-graph.show()
+# graph.calculate_external_servers_stats()
+graph.save_html(f'{os.path.expanduser("~")}/{graph.graph_name}.html')
+# graph.show()
